# snipped

> **snippet** helps you organize, synchronize and use your snippets.


[![Build Status](http://img.shields.io/travis/com/dexpota/snipped.svg?style=flat-square)](https://travis-ci.com/dexpota/snipped)
[![License](http://img.shields.io/:license-mit-blue.svg?style=flat-square)](http://dexpota.mit-license.org)


## Installation

You can install the latest released version of **snipped** using `pip`.

`pip install snipped`

Alternativaly you can install it from the source code.

```bash
git clone git@github.com:dexpota/snipped.git
cd snipped
pip install -e .
```
